# Generated by Django 3.2.25 on 2025-09-29 13:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0092_calendar_event_effective_times'),
    ]

    operations = [
        migrations.AlterField(
            model_name='registrationlink',
            name='slug',
            field=models.SlugField(editable=False, max_length=64, unique=True),
        ),
        migrations.AlterField(
            model_name='timesheetentrytype',
            name='name',
            field=models.CharField(max_length=150, unique=True, verbose_name='name'),
        ),
        migrations.AlterUniqueTogether(
            name='timesheetperiod',
            unique_together={('start', 'end')},
        ),
    ]
